pub enum DependencyMode {
Required,
Optional {
hidden: bool,
},
Independent,
}Expand description
Describes the relationship of a compatible dependency.
Variants
Required
The dependency is required.
Optional
The dependency is optional, and may optionally be hidden from view on the mod portal.
Fields
Independent
The dependency is independent, it will not affect the load order of the mod that listed the dependency.