pub struct ModInfoBuilder { /* private fields */ }Expand description
Implementations
Sourceimpl ModInfoBuilder
Contains methods to successively build up a ModInfo struct.
impl ModInfoBuilder
Contains methods to successively build up a ModInfo struct.
Sourcepub fn description<T: Into<String>>(&mut self, description: T) -> &mut Self
pub fn description<T: Into<String>>(&mut self, description: T) -> &mut Self
Sets the description field.
Sourcepub fn factorio_version(
&mut self,
factorio_version: FactorioVersion,
) -> &mut Self
pub fn factorio_version( &mut self, factorio_version: FactorioVersion, ) -> &mut Self
Sets the factorio_version field.
Sourcepub fn dependency(&mut self, dependency: Dependency) -> &mut Self
pub fn dependency(&mut self, dependency: Dependency) -> &mut Self
Adds a dependency to dependencies.
Sourcepub fn dependencies(&mut self, dependencies: &[Dependency]) -> &mut Self
pub fn dependencies(&mut self, dependencies: &[Dependency]) -> &mut Self
Adds multiple dependencies at once to dependencies.
Sourcepub fn information_path<T: Into<PathBuf>>(&mut self, path: T) -> &mut Self
pub fn information_path<T: Into<PathBuf>>(&mut self, path: T) -> &mut Self
Sets a path to the readme file that should be displayed on the mod portal.
The path is relative to where the info.json file is located.
Note: This is an unofficial extension to the info.json format.
Sourcepub fn faq_path<T: Into<PathBuf>>(&mut self, path: T) -> &mut Self
pub fn faq_path<T: Into<PathBuf>>(&mut self, path: T) -> &mut Self
Sets a path to the FAQ file that should be displayed on the mod portal.
The path is relative to where the info.json file is located.