ModPackageInfo

Struct ModPackageInfo 

pub struct ModPackageInfo {
    pub readme_path: Option<PathBuf>,
    pub faq_path: Option<PathBuf>,
    pub gallery_paths: Vec<PathBuf>,
}
Contains unofficial extensions to the info.json format.

Used by third party packaging tools.

Fields

readme_path: Option<PathBuf>

The path to a file that should be used as the content for the “information” page on the mod portal.

The mod portal supports markdown formatting, so it’s recommended to specify the path to a markdown file here.

Note that this path is considered relative to the info.json file (unless an absolute path is specified).

faq_path: Option<PathBuf>

The path to a file that should be used as the content for the “FAQ” page on the mod portal.

The mod portal supports markdown formatting, so it’s recommended to specify the path to a markdown file here.

Note that this path is considered relative to the info.json file (unless an absolute path is specified).

gallery_paths: Vec<PathBuf>

Paths to images that should be displayed on the mod portal.

If mod details are updated with Facti, the images will be displayed on the mod portal in the same order that they are specified in this Vec.

Note that these paths are considered relative to the info.json file (unless absolute paths are specified).