pub enum VersionReq {
Latest,
Spec(VersionSpec),
}Expand description
Represents a version requirement.
Variants
Latest
Used when the latest version is desired.
Spec(VersionSpec)
Used when a specific version is required, or one that matches a predicate.
Implementations
Sourceimpl VersionReq
impl VersionReq
Sourcepub fn parse(s: &str) -> Result<Self, ParseVersionReqError>
pub fn parse(s: &str) -> Result<Self, ParseVersionReqError>
Parses a string into a VersionReq.
Examples
let exact_req = VersionReq::parse("= 1.2.3")?;
let latest = VersionReq::parse("")?;Trait Implementations
Sourceimpl Clone for VersionReq
impl Clone for VersionReq
Sourcefn clone(&self) -> VersionReq
fn clone(&self) -> VersionReq
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VersionReq
impl Debug for VersionReq
Sourceimpl Display for VersionReq
impl Display for VersionReq
Sourceimpl From<VersionReq> for VersionReq
impl From<VersionReq> for VersionReq
Sourcefn from(value: VersionReq) -> Self
fn from(value: VersionReq) -> Self
Converts to this type from the input type.
Sourceimpl FromStr for VersionReq
impl FromStr for VersionReq
Sourceimpl PartialEq for VersionReq
impl PartialEq for VersionReq
Sourceimpl TryFrom<VersionReq> for VersionReq
impl TryFrom<VersionReq> for VersionReq
Sourcetype Error = ParseVersionReqError
type Error = ParseVersionReqError
The type returned in the event of a conversion error.
impl Copy for VersionReq
impl Eq for VersionReq
impl StructuralPartialEq for VersionReq